==> plantuml-1.2022.3.tar.gz: plantuml-1.2022.3/src/net/sourceforge/plantuml/svek/extremity/ExtremityFactoryExtendsLike.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Creator:  Hisashi Miyashita
 *
 * 
 */
package net.sourceforge.plantuml.svek.extremity;

import java.awt.geom.Point2D;

import net.sourceforge.plantuml.graphic.UDrawable;
import net.sourceforge.plantuml.svek.AbstractExtremityFactory;
import net.sourceforge.plantuml.svek.Side;
import net.sourceforge.plantuml.ugraphic.color.HColor;

public class ExtremityFactoryExtendsLike extends AbstractExtremityFactory implements ExtremityFactory {

	private final HColor backgroundColor;
	private final boolean definedBy;

	public ExtremityFactoryExtendsLike(HColor backgroundColor, boolean definedBy) {
		this.backgroundColor = backgroundColor;
		this.definedBy = definedBy;
	}

	@Override
	public UDrawable createUDrawable(Point2D p0, double angle, Side side) {
		if (definedBy) {
			return new ExtremityExtendsLike.DefinedBy(p0, angle, backgroundColor);
		} else {
			return new ExtremityExtendsLike.Redefines(p0, angle, backgroundColor);
		}
	}

	public UDrawable createUDrawable(Point2D p0, Point2D p1, Point2D p2, Side side) {
		final double ortho = atan2(p0, p2) + (Math.PI / 2.0);
		if (definedBy) {
			return new ExtremityExtendsLike.DefinedBy(p1, ortho, backgroundColor);
		} else {
			return new ExtremityExtendsLike.Redefines(p1, ortho, backgroundColor);
		}
	}
}

==> plantuml-1.2022.11.tar.gz: plantuml-1.2022.11/src/net/sourceforge/plantuml/svek/extremity/ExtremityFactoryExtendsLike.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Creator:  Hisashi Miyashita
 *
 * 
 */
package net.sourceforge.plantuml.svek.extremity;

import net.sourceforge.plantuml.awt.geom.XPoint2D;
import net.sourceforge.plantuml.graphic.UDrawable;
import net.sourceforge.plantuml.svek.AbstractExtremityFactory;
import net.sourceforge.plantuml.svek.Side;
import net.sourceforge.plantuml.ugraphic.color.HColor;

public class ExtremityFactoryExtendsLike extends AbstractExtremityFactory implements ExtremityFactory {

	private final HColor backgroundColor;
	private final boolean definedBy;

	public ExtremityFactoryExtendsLike(HColor backgroundColor, boolean definedBy) {
		this.backgroundColor = backgroundColor;
		this.definedBy = definedBy;
	}

	@Override
	public UDrawable createUDrawable(XPoint2D p0, double angle, Side side) {
		if (definedBy) {
			return new ExtremityExtendsLike.DefinedBy(p0, angle, backgroundColor);
		} else {
			return new ExtremityExtendsLike.Redefines(p0, angle, backgroundColor);
		}
	}

	@Override
	public UDrawable createUDrawable(XPoint2D p0, XPoint2D p1, XPoint2D p2, Side side) {
		final double ortho = atan2(p0, p2) + (Math.PI / 2.0);
		if (definedBy) {
			return new ExtremityExtendsLike.DefinedBy(p1, ortho, backgroundColor);
		} else {
			return new ExtremityExtendsLike.Redefines(p1, ortho, backgroundColor);
		}
	}
}
